"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AssociationTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___AssociationTarget = AssociationTarget

@typing_extensions.final
class AssociationS3OutputLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OUTPUT_S3_REGION_FIELD_NUMBER: builtins.int
    OUTPUT_S3_BUCKET_NAME_FIELD_NUMBER: builtins.int
    OUTPUT_S3_KEY_PREFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    output_s3_region: builtins.str
    output_s3_bucket_name: builtins.str
    output_s3_key_prefix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        output_s3_region: builtins.str = ...,
        output_s3_bucket_name: builtins.str = ...,
        output_s3_key_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["output_s3_bucket_name", b"output_s3_bucket_name", "output_s3_key_prefix", b"output_s3_key_prefix", "output_s3_region", b"output_s3_region", "resource_info", b"resource_info"]) -> None: ...

global___AssociationS3OutputLocation = AssociationS3OutputLocation

@typing_extensions.final
class AssociationInstanceAssociationOutputLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def s3_location(self) -> global___AssociationS3OutputLocation: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_location: global___AssociationS3OutputLocation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_location", b"s3_location"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_location", b"s3_location"]) -> None: ...

global___AssociationInstanceAssociationOutputLocation = AssociationInstanceAssociationOutputLocation

@typing_extensions.final
class Association(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ASSOCIATION_NAME_FIELD_NUMBER: builtins.int
    DOCUMENT_VERSION_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    SCHEDULE_EXPRESSION_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    OUTPUT_LOCATION_FIELD_NUMBER: builtins.int
    AUTOMATION_TARGET_PARAMETER_NAME_FIELD_NUMBER: builtins.int
    MAX_ERRORS_FIELD_NUMBER: builtins.int
    MAX_CONCURRENCY_FIELD_NUMBER: builtins.int
    COMPLIANCE_SEVERITY_FIELD_NUMBER: builtins.int
    SYNC_COMPLIANCE_FIELD_NUMBER: builtins.int
    WAIT_FOR_SUCCESS_TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    APPLY_ONLY_AT_CRON_INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    association_name: builtins.str
    document_version: builtins.str
    instance_id: builtins.str
    name: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    schedule_expression: builtins.str
    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssociationTarget]: ...
    @property
    def output_location(self) -> global___AssociationInstanceAssociationOutputLocation: ...
    automation_target_parameter_name: builtins.str
    max_errors: builtins.str
    max_concurrency: builtins.str
    compliance_severity: builtins.str
    sync_compliance: builtins.str
    wait_for_success_timeout_seconds: builtins.int
    apply_only_at_cron_interval: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        association_name: builtins.str = ...,
        document_version: builtins.str = ...,
        instance_id: builtins.str = ...,
        name: builtins.str = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        schedule_expression: builtins.str = ...,
        targets: collections.abc.Iterable[global___AssociationTarget] | None = ...,
        output_location: global___AssociationInstanceAssociationOutputLocation | None = ...,
        automation_target_parameter_name: builtins.str = ...,
        max_errors: builtins.str = ...,
        max_concurrency: builtins.str = ...,
        compliance_severity: builtins.str = ...,
        sync_compliance: builtins.str = ...,
        wait_for_success_timeout_seconds: builtins.int = ...,
        apply_only_at_cron_interval: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["output_location", b"output_location", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apply_only_at_cron_interval", b"apply_only_at_cron_interval", "association_name", b"association_name", "automation_target_parameter_name", b"automation_target_parameter_name", "compliance_severity", b"compliance_severity", "document_version", b"document_version", "instance_id", b"instance_id", "max_concurrency", b"max_concurrency", "max_errors", b"max_errors", "name", b"name", "output_location", b"output_location", "parameters", b"parameters", "resource_info", b"resource_info", "schedule_expression", b"schedule_expression", "sync_compliance", b"sync_compliance", "targets", b"targets", "wait_for_success_timeout_seconds", b"wait_for_success_timeout_seconds"]) -> None: ...

global___Association = Association

@typing_extensions.final
class SSM(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSOCIATION_FIELD_NUMBER: builtins.int
    DOCUMENT_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_TARGET_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_TASK_FIELD_NUMBER: builtins.int
    PARAMETER_FIELD_NUMBER: builtins.int
    PATCH_BASELINE_FIELD_NUMBER: builtins.int
    RESOURCE_DATA_SYNC_FIELD_NUMBER: builtins.int
    ASSOCIATION_PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    @property
    def association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Association]: ...
    @property
    def document(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Document]: ...
    @property
    def maintenance_window(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MaintenanceWindow]: ...
    @property
    def maintenance_window_target(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MaintenanceWindowTarget]: ...
    @property
    def maintenance_window_task(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MaintenanceWindowTask]: ...
    @property
    def parameter(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Parameter]: ...
    @property
    def patch_baseline(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PatchBaseline]: ...
    @property
    def resource_data_sync(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceDataSync]: ...
    @property
    def association_parameter_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssociationParameterValues]: ...
    def __init__(
        self,
        *,
        association: collections.abc.Iterable[global___Association] | None = ...,
        document: collections.abc.Iterable[global___Document] | None = ...,
        maintenance_window: collections.abc.Iterable[global___MaintenanceWindow] | None = ...,
        maintenance_window_target: collections.abc.Iterable[global___MaintenanceWindowTarget] | None = ...,
        maintenance_window_task: collections.abc.Iterable[global___MaintenanceWindowTask] | None = ...,
        parameter: collections.abc.Iterable[global___Parameter] | None = ...,
        patch_baseline: collections.abc.Iterable[global___PatchBaseline] | None = ...,
        resource_data_sync: collections.abc.Iterable[global___ResourceDataSync] | None = ...,
        association_parameter_values: collections.abc.Iterable[global___AssociationParameterValues] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["association", b"association", "association_parameter_values", b"association_parameter_values", "document", b"document", "maintenance_window", b"maintenance_window", "maintenance_window_target", b"maintenance_window_target", "maintenance_window_task", b"maintenance_window_task", "parameter", b"parameter", "patch_baseline", b"patch_baseline", "resource_data_sync", b"resource_data_sync"]) -> None: ...

global___SSM = SSM

@typing_extensions.final
class Document(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ContentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    DOCUMENT_TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def content(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    document_type: builtins.str
    name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        content: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        document_type: builtins.str = ...,
        name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "document_type", b"document_type", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Document = Document

@typing_extensions.final
class MaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ALLOW_UNASSOCIATED_TARGETS_FIELD_NUMBER: builtins.int
    CUTOFF_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SCHEDULE_OFFSET_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SCHEDULE_TIMEZONE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    start_date: builtins.str
    description: builtins.str
    allow_unassociated_targets: builtins.bool
    cutoff: builtins.int
    schedule: builtins.str
    duration: builtins.int
    schedule_offset: builtins.int
    end_date: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    schedule_timezone: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        start_date: builtins.str = ...,
        description: builtins.str = ...,
        allow_unassociated_targets: builtins.bool = ...,
        cutoff: builtins.int = ...,
        schedule: builtins.str = ...,
        duration: builtins.int = ...,
        schedule_offset: builtins.int = ...,
        end_date: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        schedule_timezone: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_unassociated_targets", b"allow_unassociated_targets", "cutoff", b"cutoff", "description", b"description", "duration", b"duration", "end_date", b"end_date", "name", b"name", "resource_info", b"resource_info", "schedule", b"schedule", "schedule_offset", b"schedule_offset", "schedule_timezone", b"schedule_timezone", "start_date", b"start_date", "tags", b"tags"]) -> None: ...

global___MaintenanceWindow = MaintenanceWindow

@typing_extensions.final
class MaintenanceWindowTargetTargets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___MaintenanceWindowTargetTargets = MaintenanceWindowTargetTargets

@typing_extensions.final
class MaintenanceWindowTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OWNER_INFORMATION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    WINDOW_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    owner_information: builtins.str
    description: builtins.str
    window_id: builtins.str
    resource_type: builtins.str
    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MaintenanceWindowTargetTargets]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        owner_information: builtins.str = ...,
        description: builtins.str = ...,
        window_id: builtins.str = ...,
        resource_type: builtins.str = ...,
        targets: collections.abc.Iterable[global___MaintenanceWindowTargetTargets] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "owner_information", b"owner_information", "resource_info", b"resource_info", "resource_type", b"resource_type", "targets", b"targets", "window_id", b"window_id"]) -> None: ...

global___MaintenanceWindowTarget = MaintenanceWindowTarget

@typing_extensions.final
class MaintenanceWindowTaskTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___MaintenanceWindowTaskTarget = MaintenanceWindowTaskTarget

@typing_extensions.final
class MaintenanceWindowTaskNotificationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NOTIFICATION_ARN_FIELD_NUMBER: builtins.int
    NOTIFICATION_TYPE_FIELD_NUMBER: builtins.int
    NOTIFICATION_EVENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    notification_arn: builtins.str
    notification_type: builtins.str
    @property
    def notification_events(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        notification_arn: builtins.str = ...,
        notification_type: builtins.str = ...,
        notification_events: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_arn", b"notification_arn", "notification_events", b"notification_events", "notification_type", b"notification_type", "resource_info", b"resource_info"]) -> None: ...

global___MaintenanceWindowTaskNotificationConfig = MaintenanceWindowTaskNotificationConfig

@typing_extensions.final
class MaintenanceWindowTaskMaintenanceWindowRunCommandParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    OUTPUT_S3_KEY_PREFIX_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    DOCUMENT_HASH_TYPE_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_ARN_FIELD_NUMBER: builtins.int
    NOTIFICATION_CONFIG_FIELD_NUMBER: builtins.int
    OUTPUT_S3_BUCKET_NAME_FIELD_NUMBER: builtins.int
    DOCUMENT_HASH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    timeout_seconds: builtins.int
    comment: builtins.str
    output_s3_key_prefix: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    document_hash_type: builtins.str
    service_role_arn: builtins.str
    @property
    def notification_config(self) -> global___MaintenanceWindowTaskNotificationConfig: ...
    output_s3_bucket_name: builtins.str
    document_hash: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        timeout_seconds: builtins.int = ...,
        comment: builtins.str = ...,
        output_s3_key_prefix: builtins.str = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        document_hash_type: builtins.str = ...,
        service_role_arn: builtins.str = ...,
        notification_config: global___MaintenanceWindowTaskNotificationConfig | None = ...,
        output_s3_bucket_name: builtins.str = ...,
        document_hash: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notification_config", b"notification_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment", b"comment", "document_hash", b"document_hash", "document_hash_type", b"document_hash_type", "notification_config", b"notification_config", "output_s3_bucket_name", b"output_s3_bucket_name", "output_s3_key_prefix", b"output_s3_key_prefix", "parameters", b"parameters", "resource_info", b"resource_info", "service_role_arn", b"service_role_arn", "timeout_seconds", b"timeout_seconds"]) -> None: ...

global___MaintenanceWindowTaskMaintenanceWindowRunCommandParameters = MaintenanceWindowTaskMaintenanceWindowRunCommandParameters

@typing_extensions.final
class MaintenanceWindowTaskMaintenanceWindowAutomationParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    DOCUMENT_VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    document_version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        document_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["document_version", b"document_version", "parameters", b"parameters", "resource_info", b"resource_info"]) -> None: ...

global___MaintenanceWindowTaskMaintenanceWindowAutomationParameters = MaintenanceWindowTaskMaintenanceWindowAutomationParameters

@typing_extensions.final
class MaintenanceWindowTaskMaintenanceWindowStepFunctionsParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    input: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        input: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input", b"input", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___MaintenanceWindowTaskMaintenanceWindowStepFunctionsParameters = MaintenanceWindowTaskMaintenanceWindowStepFunctionsParameters

@typing_extensions.final
class MaintenanceWindowTaskMaintenanceWindowLambdaParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLIENT_CONTEXT_FIELD_NUMBER: builtins.int
    QUALIFIER_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    client_context: builtins.str
    qualifier: builtins.str
    payload: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        client_context: builtins.str = ...,
        qualifier: builtins.str = ...,
        payload: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_context", b"client_context", "payload", b"payload", "qualifier", b"qualifier", "resource_info", b"resource_info"]) -> None: ...

global___MaintenanceWindowTaskMaintenanceWindowLambdaParameters = MaintenanceWindowTaskMaintenanceWindowLambdaParameters

@typing_extensions.final
class MaintenanceWindowTaskTaskInvocationParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_RUN_COMMAND_PARAMETERS_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_AUTOMATION_PARAMETERS_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_STEP_FUNCTIONS_PARAMETERS_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_LAMBDA_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def maintenance_window_run_command_parameters(self) -> global___MaintenanceWindowTaskMaintenanceWindowRunCommandParameters: ...
    @property
    def maintenance_window_automation_parameters(self) -> global___MaintenanceWindowTaskMaintenanceWindowAutomationParameters: ...
    @property
    def maintenance_window_step_functions_parameters(self) -> global___MaintenanceWindowTaskMaintenanceWindowStepFunctionsParameters: ...
    @property
    def maintenance_window_lambda_parameters(self) -> global___MaintenanceWindowTaskMaintenanceWindowLambdaParameters: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        maintenance_window_run_command_parameters: global___MaintenanceWindowTaskMaintenanceWindowRunCommandParameters | None = ...,
        maintenance_window_automation_parameters: global___MaintenanceWindowTaskMaintenanceWindowAutomationParameters | None = ...,
        maintenance_window_step_functions_parameters: global___MaintenanceWindowTaskMaintenanceWindowStepFunctionsParameters | None = ...,
        maintenance_window_lambda_parameters: global___MaintenanceWindowTaskMaintenanceWindowLambdaParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["maintenance_window_automation_parameters", b"maintenance_window_automation_parameters", "maintenance_window_lambda_parameters", b"maintenance_window_lambda_parameters", "maintenance_window_run_command_parameters", b"maintenance_window_run_command_parameters", "maintenance_window_step_functions_parameters", b"maintenance_window_step_functions_parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["maintenance_window_automation_parameters", b"maintenance_window_automation_parameters", "maintenance_window_lambda_parameters", b"maintenance_window_lambda_parameters", "maintenance_window_run_command_parameters", b"maintenance_window_run_command_parameters", "maintenance_window_step_functions_parameters", b"maintenance_window_step_functions_parameters", "resource_info", b"resource_info"]) -> None: ...

global___MaintenanceWindowTaskTaskInvocationParameters = MaintenanceWindowTaskTaskInvocationParameters

@typing_extensions.final
class MaintenanceWindowTaskLoggingInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    S3_PREFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_bucket: builtins.str
    region: builtins.str
    s3_prefix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_bucket: builtins.str = ...,
        region: builtins.str = ...,
        s3_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["region", b"region", "resource_info", b"resource_info", "s3_bucket", b"s3_bucket", "s3_prefix", b"s3_prefix"]) -> None: ...

global___MaintenanceWindowTaskLoggingInfo = MaintenanceWindowTaskLoggingInfo

@typing_extensions.final
class MaintenanceWindowTask(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TaskParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAX_ERRORS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_ARN_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    MAX_CONCURRENCY_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TASK_ARN_FIELD_NUMBER: builtins.int
    TASK_INVOCATION_PARAMETERS_FIELD_NUMBER: builtins.int
    WINDOW_ID_FIELD_NUMBER: builtins.int
    TASK_PARAMETERS_FIELD_NUMBER: builtins.int
    TASK_TYPE_FIELD_NUMBER: builtins.int
    LOGGING_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    max_errors: builtins.str
    description: builtins.str
    service_role_arn: builtins.str
    priority: builtins.int
    max_concurrency: builtins.str
    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MaintenanceWindowTaskTarget]: ...
    name: builtins.str
    task_arn: builtins.str
    @property
    def task_invocation_parameters(self) -> global___MaintenanceWindowTaskTaskInvocationParameters: ...
    window_id: builtins.str
    @property
    def task_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    task_type: builtins.str
    @property
    def logging_info(self) -> global___MaintenanceWindowTaskLoggingInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        max_errors: builtins.str = ...,
        description: builtins.str = ...,
        service_role_arn: builtins.str = ...,
        priority: builtins.int = ...,
        max_concurrency: builtins.str = ...,
        targets: collections.abc.Iterable[global___MaintenanceWindowTaskTarget] | None = ...,
        name: builtins.str = ...,
        task_arn: builtins.str = ...,
        task_invocation_parameters: global___MaintenanceWindowTaskTaskInvocationParameters | None = ...,
        window_id: builtins.str = ...,
        task_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        task_type: builtins.str = ...,
        logging_info: global___MaintenanceWindowTaskLoggingInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_info", b"logging_info", "resource_info", b"resource_info", "task_invocation_parameters", b"task_invocation_parameters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "logging_info", b"logging_info", "max_concurrency", b"max_concurrency", "max_errors", b"max_errors", "name", b"name", "priority", b"priority", "resource_info", b"resource_info", "service_role_arn", b"service_role_arn", "targets", b"targets", "task_arn", b"task_arn", "task_invocation_parameters", b"task_invocation_parameters", "task_parameters", b"task_parameters", "task_type", b"task_type", "window_id", b"window_id"]) -> None: ...

global___MaintenanceWindowTask = MaintenanceWindowTask

@typing_extensions.final
class Parameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    POLICIES_FIELD_NUMBER: builtins.int
    ALLOWED_PATTERN_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    DATA_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    type: builtins.str
    description: builtins.str
    policies: builtins.str
    allowed_pattern: builtins.str
    tier: builtins.str
    value: builtins.str
    data_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        type: builtins.str = ...,
        description: builtins.str = ...,
        policies: builtins.str = ...,
        allowed_pattern: builtins.str = ...,
        tier: builtins.str = ...,
        value: builtins.str = ...,
        data_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_pattern", b"allowed_pattern", "data_type", b"data_type", "description", b"description", "name", b"name", "policies", b"policies", "resource_info", b"resource_info", "tags", b"tags", "tier", b"tier", "type", b"type", "value", b"value"]) -> None: ...

global___Parameter = Parameter

@typing_extensions.final
class PatchBaselinePatchStringDate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___PatchBaselinePatchStringDate = PatchBaselinePatchStringDate

@typing_extensions.final
class PatchBaselinePatchFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___PatchBaselinePatchFilter = PatchBaselinePatchFilter

@typing_extensions.final
class PatchBaselinePatchFilterGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATCH_FILTERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def patch_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PatchBaselinePatchFilter]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        patch_filters: collections.abc.Iterable[global___PatchBaselinePatchFilter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["patch_filters", b"patch_filters", "resource_info", b"resource_info"]) -> None: ...

global___PatchBaselinePatchFilterGroup = PatchBaselinePatchFilterGroup

@typing_extensions.final
class PatchBaselineRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPROVE_UNTIL_DATE_FIELD_NUMBER: builtins.int
    ENABLE_NON_SECURITY_FIELD_NUMBER: builtins.int
    PATCH_FILTER_GROUP_FIELD_NUMBER: builtins.int
    APPROVE_AFTER_DAYS_FIELD_NUMBER: builtins.int
    COMPLIANCE_LEVEL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def approve_until_date(self) -> global___PatchBaselinePatchStringDate: ...
    enable_non_security: builtins.bool
    @property
    def patch_filter_group(self) -> global___PatchBaselinePatchFilterGroup: ...
    approve_after_days: builtins.int
    compliance_level: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        approve_until_date: global___PatchBaselinePatchStringDate | None = ...,
        enable_non_security: builtins.bool = ...,
        patch_filter_group: global___PatchBaselinePatchFilterGroup | None = ...,
        approve_after_days: builtins.int = ...,
        compliance_level: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["approve_until_date", b"approve_until_date", "patch_filter_group", b"patch_filter_group", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["approve_after_days", b"approve_after_days", "approve_until_date", b"approve_until_date", "compliance_level", b"compliance_level", "enable_non_security", b"enable_non_security", "patch_filter_group", b"patch_filter_group", "resource_info", b"resource_info"]) -> None: ...

global___PatchBaselineRule = PatchBaselineRule

@typing_extensions.final
class PatchBaselineRuleGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PATCH_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def patch_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PatchBaselineRule]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        patch_rules: collections.abc.Iterable[global___PatchBaselineRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["patch_rules", b"patch_rules", "resource_info", b"resource_info"]) -> None: ...

global___PatchBaselineRuleGroup = PatchBaselineRuleGroup

@typing_extensions.final
class PatchBaselinePatchSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PRODUCTS_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def products(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    configuration: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        products: collections.abc.Iterable[builtins.str] | None = ...,
        configuration: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "name", b"name", "products", b"products", "resource_info", b"resource_info"]) -> None: ...

global___PatchBaselinePatchSource = PatchBaselinePatchSource

@typing_extensions.final
class PatchBaseline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OPERATING_SYSTEM_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    APPROVAL_RULES_FIELD_NUMBER: builtins.int
    SOURCES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REJECTED_PATCHES_FIELD_NUMBER: builtins.int
    APPROVED_PATCHES_FIELD_NUMBER: builtins.int
    REJECTED_PATCHES_ACTION_FIELD_NUMBER: builtins.int
    PATCH_GROUPS_FIELD_NUMBER: builtins.int
    APPROVED_PATCHES_COMPLIANCE_LEVEL_FIELD_NUMBER: builtins.int
    APPROVED_PATCHES_ENABLE_NON_SECURITY_FIELD_NUMBER: builtins.int
    GLOBAL_FILTERS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    operating_system: builtins.str
    description: builtins.str
    @property
    def approval_rules(self) -> global___PatchBaselineRuleGroup: ...
    @property
    def sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PatchBaselinePatchSource]: ...
    name: builtins.str
    @property
    def rejected_patches(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def approved_patches(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    rejected_patches_action: builtins.str
    @property
    def patch_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    approved_patches_compliance_level: builtins.str
    approved_patches_enable_non_security: builtins.bool
    @property
    def global_filters(self) -> global___PatchBaselinePatchFilterGroup: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        operating_system: builtins.str = ...,
        description: builtins.str = ...,
        approval_rules: global___PatchBaselineRuleGroup | None = ...,
        sources: collections.abc.Iterable[global___PatchBaselinePatchSource] | None = ...,
        name: builtins.str = ...,
        rejected_patches: collections.abc.Iterable[builtins.str] | None = ...,
        approved_patches: collections.abc.Iterable[builtins.str] | None = ...,
        rejected_patches_action: builtins.str = ...,
        patch_groups: collections.abc.Iterable[builtins.str] | None = ...,
        approved_patches_compliance_level: builtins.str = ...,
        approved_patches_enable_non_security: builtins.bool = ...,
        global_filters: global___PatchBaselinePatchFilterGroup | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["approval_rules", b"approval_rules", "global_filters", b"global_filters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["approval_rules", b"approval_rules", "approved_patches", b"approved_patches", "approved_patches_compliance_level", b"approved_patches_compliance_level", "approved_patches_enable_non_security", b"approved_patches_enable_non_security", "description", b"description", "global_filters", b"global_filters", "name", b"name", "operating_system", b"operating_system", "patch_groups", b"patch_groups", "rejected_patches", b"rejected_patches", "rejected_patches_action", b"rejected_patches_action", "resource_info", b"resource_info", "sources", b"sources", "tags", b"tags"]) -> None: ...

global___PatchBaseline = PatchBaseline

@typing_extensions.final
class ResourceDataSyncS3Destination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    BUCKET_NAME_FIELD_NUMBER: builtins.int
    BUCKET_REGION_FIELD_NUMBER: builtins.int
    SYNC_FORMAT_FIELD_NUMBER: builtins.int
    BUCKET_PREFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kms_key_arn: builtins.str
    bucket_name: builtins.str
    bucket_region: builtins.str
    sync_format: builtins.str
    bucket_prefix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kms_key_arn: builtins.str = ...,
        bucket_name: builtins.str = ...,
        bucket_region: builtins.str = ...,
        sync_format: builtins.str = ...,
        bucket_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "bucket_prefix", b"bucket_prefix", "bucket_region", b"bucket_region", "kms_key_arn", b"kms_key_arn", "resource_info", b"resource_info", "sync_format", b"sync_format"]) -> None: ...

global___ResourceDataSyncS3Destination = ResourceDataSyncS3Destination

@typing_extensions.final
class ResourceDataSyncAwsOrganizationsSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ORGANIZATION_SOURCE_TYPE_FIELD_NUMBER: builtins.int
    ORGANIZATIONAL_UNITS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    organization_source_type: builtins.str
    @property
    def organizational_units(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        organization_source_type: builtins.str = ...,
        organizational_units: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["organization_source_type", b"organization_source_type", "organizational_units", b"organizational_units", "resource_info", b"resource_info"]) -> None: ...

global___ResourceDataSyncAwsOrganizationsSource = ResourceDataSyncAwsOrganizationsSource

@typing_extensions.final
class ResourceDataSyncSyncSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    AWS_ORGANIZATIONS_SOURCE_FIELD_NUMBER: builtins.int
    INCLUDE_FUTURE_REGIONS_FIELD_NUMBER: builtins.int
    SOURCE_REGIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    source_type: builtins.str
    @property
    def aws_organizations_source(self) -> global___ResourceDataSyncAwsOrganizationsSource: ...
    include_future_regions: builtins.bool
    @property
    def source_regions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        source_type: builtins.str = ...,
        aws_organizations_source: global___ResourceDataSyncAwsOrganizationsSource | None = ...,
        include_future_regions: builtins.bool = ...,
        source_regions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_organizations_source", b"aws_organizations_source", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_organizations_source", b"aws_organizations_source", "include_future_regions", b"include_future_regions", "resource_info", b"resource_info", "source_regions", b"source_regions", "source_type", b"source_type"]) -> None: ...

global___ResourceDataSyncSyncSource = ResourceDataSyncSyncSource

@typing_extensions.final
class ResourceDataSync(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_DESTINATION_FIELD_NUMBER: builtins.int
    KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    SYNC_SOURCE_FIELD_NUMBER: builtins.int
    BUCKET_NAME_FIELD_NUMBER: builtins.int
    BUCKET_REGION_FIELD_NUMBER: builtins.int
    SYNC_FORMAT_FIELD_NUMBER: builtins.int
    SYNC_NAME_FIELD_NUMBER: builtins.int
    SYNC_TYPE_FIELD_NUMBER: builtins.int
    BUCKET_PREFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def s3_destination(self) -> global___ResourceDataSyncS3Destination: ...
    kms_key_arn: builtins.str
    @property
    def sync_source(self) -> global___ResourceDataSyncSyncSource: ...
    bucket_name: builtins.str
    bucket_region: builtins.str
    sync_format: builtins.str
    sync_name: builtins.str
    sync_type: builtins.str
    bucket_prefix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_destination: global___ResourceDataSyncS3Destination | None = ...,
        kms_key_arn: builtins.str = ...,
        sync_source: global___ResourceDataSyncSyncSource | None = ...,
        bucket_name: builtins.str = ...,
        bucket_region: builtins.str = ...,
        sync_format: builtins.str = ...,
        sync_name: builtins.str = ...,
        sync_type: builtins.str = ...,
        bucket_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_destination", b"s3_destination", "sync_source", b"sync_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "bucket_prefix", b"bucket_prefix", "bucket_region", b"bucket_region", "kms_key_arn", b"kms_key_arn", "resource_info", b"resource_info", "s3_destination", b"s3_destination", "sync_format", b"sync_format", "sync_name", b"sync_name", "sync_source", b"sync_source", "sync_type", b"sync_type"]) -> None: ...

global___ResourceDataSync = ResourceDataSync

@typing_extensions.final
class AssociationParameterValues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def parameter_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        parameter_values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameter_values", b"parameter_values", "resource_info", b"resource_info"]) -> None: ...

global___AssociationParameterValues = AssociationParameterValues



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_access.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gcp/gcp_access.proto\x12\x16oak9.tython.gcp.access\x1a\x13shared/shared.proto\"\x9b\x01\nKAccessContextManagerAccessLevelXBasicXConditionsXDevicePolicyXOsConstraints\x12\x17\n\x0fminimum_version\x18\x01 \x01(\t\x12\x0f\n\x07os_type\x18\x02 \x01(\t\x12\"\n\x1arequire_verified_chrome_os\x18\x03 \x01(\x08\"\xe4\x02\n=AccessContextManagerAccessLevelXBasicXConditionsXDevicePolicy\x12(\n allowed_device_management_levels\x18\x01 \x03(\t\x12#\n\x1b\x61llowed_encryption_statuses\x18\x02 \x03(\t\x12\x1e\n\x16require_admin_approval\x18\x03 \x01(\x08\x12\x1a\n\x12require_corp_owned\x18\x04 \x01(\x08\x12\x1b\n\x13require_screen_lock\x18\x05 \x01(\x08\x12{\n\x0eos_constraints\x18\x06 \x03(\x0b\x32\x63.oak9.tython.gcp.access.AccessContextManagerAccessLevelXBasicXConditionsXDevicePolicyXOsConstraints\"\x8a\x02\n0AccessContextManagerAccessLevelXBasicXConditions\x12\x16\n\x0eip_subnetworks\x18\x01 \x03(\t\x12\x0f\n\x07members\x18\x02 \x03(\t\x12\x0e\n\x06negate\x18\x03 \x01(\x08\x12\x0f\n\x07regions\x18\x04 \x03(\t\x12\x1e\n\x16required_access_levels\x18\x05 \x03(\t\x12l\n\rdevice_policy\x18\x06 \x01(\x0b\x32U.oak9.tython.gcp.access.AccessContextManagerAccessLevelXBasicXConditionsXDevicePolicy\"\xa1\x01\n%AccessContextManagerAccessLevelXBasic\x12\x1a\n\x12\x63ombining_function\x18\x01 \x01(\t\x12\\\n\nconditions\x18\x02 \x03(\x0b\x32H.oak9.tython.gcp.access.AccessContextManagerAccessLevelXBasicXConditions\"w\n+AccessContextManagerAccessLevelXCustomXExpr\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"{\n&AccessContextManagerAccessLevelXCustom\x12Q\n\x04\x65xpr\x18\x01 \x01(\x0b\x32\x43.oak9.tython.gcp.access.AccessContextManagerAccessLevelXCustomXExpr\"Z\n(AccessContextManagerAccessLevelXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9a\x03\n\x1f\x41\x63\x63\x65ssContextManagerAccessLevel\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12L\n\x05\x62\x61sic\x18\x06 \x01(\x0b\x32=.oak9.tython.gcp.access.AccessContextManagerAccessLevelXBasic\x12N\n\x06\x63ustom\x18\x07 \x01(\x0b\x32>.oak9.tython.gcp.access.AccessContextManagerAccessLevelXCustom\x12R\n\x08timeouts\x18\x08 \x01(\x0b\x32@.oak9.tython.gcp.access.AccessContextManagerAccessLevelXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"o\nCAccessContextManagerAccessLevelConditionXDevicePolicyXOsConstraints\x12\x17\n\x0fminimum_version\x18\x01 \x01(\t\x12\x0f\n\x07os_type\x18\x02 \x01(\t\"\xd4\x02\n5AccessContextManagerAccessLevelConditionXDevicePolicy\x12(\n allowed_device_management_levels\x18\x01 \x03(\t\x12#\n\x1b\x61llowed_encryption_statuses\x18\x02 \x03(\t\x12\x1e\n\x16require_admin_approval\x18\x03 \x01(\x08\x12\x1a\n\x12require_corp_owned\x18\x04 \x01(\x08\x12\x1b\n\x13require_screen_lock\x18\x05 \x01(\x08\x12s\n\x0eos_constraints\x18\x06 \x03(\x0b\x32[.oak9.tython.gcp.access.AccessContextManagerAccessLevelConditionXDevicePolicyXOsConstraints\"S\n1AccessContextManagerAccessLevelConditionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xb2\x03\n(AccessContextManagerAccessLevelCondition\x12\x14\n\x0c\x61\x63\x63\x65ss_level\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x16\n\x0eip_subnetworks\x18\x03 \x03(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0e\n\x06negate\x18\x05 \x01(\x08\x12\x0f\n\x07regions\x18\x06 \x03(\t\x12\x1e\n\x16required_access_levels\x18\x07 \x03(\t\x12\x64\n\rdevice_policy\x18\x08 \x01(\x0b\x32M.oak9.tython.gcp.access.AccessContextManagerAccessLevelConditionXDevicePolicy\x12[\n\x08timeouts\x18\t \x01(\x0b\x32I.oak9.tython.gcp.access.AccessContextManagerAccessLevelConditionXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x85\x01\nYAccessContextManagerAccessLevelsXAccessLevelsXBasicXConditionsXDevicePolicyXOsConstraints\x12\x17\n\x0fminimum_version\x18\x01 \x01(\t\x12\x0f\n\x07os_type\x18\x02 \x01(\t\"\x81\x03\nKAccessContextManagerAccessLevelsXAccessLevelsXBasicXConditionsXDevicePolicy\x12(\n allowed_device_management_levels\x18\x01 \x03(\t\x12#\n\x1b\x61llowed_encryption_statuses\x18\x02 \x03(\t\x12\x1e\n\x16require_admin_approval\x18\x03 \x01(\x08\x12\x1a\n\x12require_corp_owned\x18\x04 \x01(\x08\x12\x1b\n\x13require_screen_lock\x18\x05 \x01(\x08\x12\x89\x01\n\x0eos_constraints\x18\x06 \x03(\x0b\x32q.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevelsXBasicXConditionsXDevicePolicyXOsConstraints\"\xa6\x02\n>AccessContextManagerAccessLevelsXAccessLevelsXBasicXConditions\x12\x16\n\x0eip_subnetworks\x18\x01 \x03(\t\x12\x0f\n\x07members\x18\x02 \x03(\t\x12\x0e\n\x06negate\x18\x03 \x01(\x08\x12\x0f\n\x07regions\x18\x04 \x03(\t\x12\x1e\n\x16required_access_levels\x18\x05 \x03(\t\x12z\n\rdevice_policy\x18\x06 \x01(\x0b\x32\x63.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevelsXBasicXConditionsXDevicePolicy\"\xbd\x01\n3AccessContextManagerAccessLevelsXAccessLevelsXBasic\x12\x1a\n\x12\x63ombining_function\x18\x01 \x01(\t\x12j\n\nconditions\x18\x02 \x03(\x0b\x32V.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevelsXBasicXConditions\"\x85\x01\n9AccessContextManagerAccessLevelsXAccessLevelsXCustomXExpr\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"\x97\x01\n4AccessContextManagerAccessLevelsXAccessLevelsXCustom\x12_\n\x04\x65xpr\x18\x01 \x01(\x0b\x32Q.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevelsXCustomXExpr\"\x9b\x02\n-AccessContextManagerAccessLevelsXAccessLevels\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12Z\n\x05\x62\x61sic\x18\x04 \x01(\x0b\x32K.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevelsXBasic\x12\\\n\x06\x63ustom\x18\x05 \x01(\x0b\x32L.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevelsXCustom\"[\n)AccessContextManagerAccessLevelsXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xaa\x02\n AccessContextManagerAccessLevels\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06parent\x18\x02 \x01(\t\x12\\\n\raccess_levels\x18\x03 \x03(\x0b\x32\x45.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXAccessLevels\x12S\n\x08timeouts\x18\x04 \x01(\x0b\x32\x41.oak9.tython.gcp.access.AccessContextManagerAccessLevelsXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"[\n)AccessContextManagerAccessPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa3\x02\n AccessContextManagerAccessPolicy\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x12\x0e\n\x06scopes\x18\x05 \x03(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\x13\n\x0bupdate_time\x18\x07 \x01(\t\x12S\n\x08timeouts\x18\x08 \x01(\x0b\x32\x41.oak9.tython.gcp.access.AccessContextManagerAccessPolicyXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"n\n4AccessContextManagerAccessPolicyIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8d\x02\n*AccessContextManagerAccessPolicyIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12_\n\tcondition\x18\x06 \x01(\x0b\x32L.oak9.tython.gcp.access.AccessContextManagerAccessPolicyIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"m\n3AccessContextManagerAccessPolicyIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8a\x02\n)AccessContextManagerAccessPolicyIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12^\n\tcondition\x18\x06 \x01(\x0b\x32K.oak9.tython.gcp.access.AccessContextManagerAccessPolicyIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa1\x01\n)AccessContextManagerAccessPolicyIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"c\n1AccessContextManagerGcpUserAccessBindingXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9d\x02\n(AccessContextManagerGcpUserAccessBinding\x12\x15\n\raccess_levels\x18\x01 \x03(\t\x12\x11\n\tgroup_key\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x17\n\x0forganization_id\x18\x05 \x01(\t\x12[\n\x08timeouts\x18\x06 \x01(\x0b\x32I.oak9.tython.gcp.access.AccessContextManagerGcpUserAccessBindingXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"p\nCAccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\"\x82\x01\n\\AccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xf5\x01\nLAccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x8e\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32t.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressToXOperationsXMethodSelectors\"\xec\x01\nAAccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressTo\x12\x1a\n\x12\x65xternal_resources\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12x\n\noperations\x18\x03 \x03(\x0b\x32\x64.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressToXOperations\"\x9a\x02\n8AccessContextManagerServicePerimeterXSpecXEgressPolicies\x12p\n\x0b\x65gress_from\x18\x01 \x01(\x0b\x32[.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressFrom\x12l\n\tegress_to\x18\x02 \x01(\x0b\x32Y.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXEgressPoliciesXEgressTo\"w\nMAccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressFromXSources\x12\x14\n\x0c\x61\x63\x63\x65ss_level\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\"\xea\x01\nEAccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\x12v\n\x07sources\x18\x03 \x03(\x0b\x32\x65.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressFromXSources\"\x84\x01\n^AccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xf9\x01\nNAccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x90\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32v.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressToXOperationsXMethodSelectors\"\xd4\x01\nCAccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressTo\x12\x11\n\tresources\x18\x01 \x03(\t\x12z\n\noperations\x18\x02 \x03(\x0b\x32\x66.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressToXOperations\"\xa1\x02\n9AccessContextManagerServicePerimeterXSpecXIngressPolicies\x12s\n\x0cingress_from\x18\x01 \x01(\x0b\x32].oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressFrom\x12o\n\ningress_to\x18\x02 \x01(\x0b\x32[.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXIngressPoliciesXIngressTo\"w\n?AccessContextManagerServicePerimeterXSpecXVpcAccessibleServices\x12\x18\n\x10\x61llowed_services\x18\x01 \x03(\t\x12\x1a\n\x12\x65nable_restriction\x18\x02 \x01(\x08\"\xc4\x03\n)AccessContextManagerServicePerimeterXSpec\x12\x15\n\raccess_levels\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x1b\n\x13restricted_services\x18\x03 \x03(\t\x12i\n\x0f\x65gress_policies\x18\x04 \x03(\x0b\x32P.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXEgressPolicies\x12k\n\x10ingress_policies\x18\x05 \x03(\x0b\x32Q.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXIngressPolicies\x12x\n\x17vpc_accessible_services\x18\x06 \x01(\x0b\x32W.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpecXVpcAccessibleServices\"r\nEAccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\"\x84\x01\n^AccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xf9\x01\nNAccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x90\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32v.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressToXOperationsXMethodSelectors\"\xf0\x01\nCAccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressTo\x12\x1a\n\x12\x65xternal_resources\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12z\n\noperations\x18\x03 \x03(\x0b\x32\x66.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressToXOperations\"\xa0\x02\n:AccessContextManagerServicePerimeterXStatusXEgressPolicies\x12r\n\x0b\x65gress_from\x18\x01 \x01(\x0b\x32].oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressFrom\x12n\n\tegress_to\x18\x02 \x01(\x0b\x32[.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXEgressPoliciesXEgressTo\"y\nOAccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressFromXSources\x12\x14\n\x0c\x61\x63\x63\x65ss_level\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\"\xee\x01\nGAccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\x12x\n\x07sources\x18\x03 \x03(\x0b\x32g.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressFromXSources\"\x86\x01\n`AccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xfd\x01\nPAccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x92\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32x.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressToXOperationsXMethodSelectors\"\xd8\x01\nEAccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressTo\x12\x11\n\tresources\x18\x01 \x03(\t\x12|\n\noperations\x18\x02 \x03(\x0b\x32h.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressToXOperations\"\xa7\x02\n;AccessContextManagerServicePerimeterXStatusXIngressPolicies\x12u\n\x0cingress_from\x18\x01 \x01(\x0b\x32_.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressFrom\x12q\n\ningress_to\x18\x02 \x01(\x0b\x32].oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXIngressPoliciesXIngressTo\"y\nAAccessContextManagerServicePerimeterXStatusXVpcAccessibleServices\x12\x18\n\x10\x61llowed_services\x18\x01 \x03(\t\x12\x1a\n\x12\x65nable_restriction\x18\x02 \x01(\x08\"\xcc\x03\n+AccessContextManagerServicePerimeterXStatus\x12\x15\n\raccess_levels\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x1b\n\x13restricted_services\x18\x03 \x03(\t\x12k\n\x0f\x65gress_policies\x18\x04 \x03(\x0b\x32R.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXEgressPolicies\x12m\n\x10ingress_policies\x18\x05 \x03(\x0b\x32S.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXIngressPolicies\x12z\n\x17vpc_accessible_services\x18\x06 \x01(\x0b\x32Y.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatusXVpcAccessibleServices\"_\n-AccessContextManagerServicePerimeterXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x91\x04\n$AccessContextManagerServicePerimeter\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12\x16\n\x0eperimeter_type\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x13\n\x0bupdate_time\x18\x08 \x01(\t\x12!\n\x19use_explicit_dry_run_spec\x18\t \x01(\x08\x12O\n\x04spec\x18\n \x01(\x0b\x32\x41.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXSpec\x12S\n\x06status\x18\x0b \x01(\x0b\x32\x43.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXStatus\x12W\n\x08timeouts\x18\x0c \x01(\x0b\x32\x45.oak9.tython.gcp.access.AccessContextManagerServicePerimeterXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n5AccessContextManagerServicePerimeterResourceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xfe\x01\n,AccessContextManagerServicePerimeterResource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0eperimeter_name\x18\x02 \x01(\t\x12\x10\n\x08resource\x18\x03 \x01(\t\x12_\n\x08timeouts\x18\x04 \x01(\x0b\x32M.oak9.tython.gcp.access.AccessContextManagerServicePerimeterResourceXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x83\x01\nVAccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\"\x95\x01\noAccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\x9c\x02\n_AccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\xa2\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32\x87\x01.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressToXOperationsXMethodSelectors\"\x93\x02\nTAccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressTo\x12\x1a\n\x12\x65xternal_resources\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x8b\x01\n\noperations\x18\x03 \x03(\x0b\x32w.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressToXOperations\"\xd4\x02\nKAccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPolicies\x12\x83\x01\n\x0b\x65gress_from\x18\x01 \x01(\x0b\x32n.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressFrom\x12\x7f\n\tegress_to\x18\x02 \x01(\x0b\x32l.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPoliciesXEgressTo\"\x8a\x01\n`AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressFromXSources\x12\x14\n\x0c\x61\x63\x63\x65ss_level\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\"\x91\x02\nXAccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\x12\x89\x01\n\x07sources\x18\x03 \x03(\x0b\x32x.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressFromXSources\"\x97\x01\nqAccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xa0\x02\naAccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\xa4\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32\x89\x01.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressToXOperationsXMethodSelectors\"\xfb\x01\nVAccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressTo\x12\x11\n\tresources\x18\x01 \x03(\t\x12\x8d\x01\n\noperations\x18\x02 \x03(\x0b\x32y.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressToXOperations\"\xdc\x02\nLAccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPolicies\x12\x86\x01\n\x0cingress_from\x18\x01 \x01(\x0b\x32p.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressFrom\x12\x82\x01\n\ningress_to\x18\x02 \x01(\x0b\x32n.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPoliciesXIngressTo\"\x8a\x01\nRAccessContextManagerServicePerimetersXServicePerimetersXSpecXVpcAccessibleServices\x12\x18\n\x10\x61llowed_services\x18\x01 \x03(\t\x12\x1a\n\x12\x65nable_restriction\x18\x02 \x01(\x08\"\x91\x04\n<AccessContextManagerServicePerimetersXServicePerimetersXSpec\x12\x15\n\raccess_levels\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x1b\n\x13restricted_services\x18\x03 \x03(\t\x12|\n\x0f\x65gress_policies\x18\x04 \x03(\x0b\x32\x63.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXEgressPolicies\x12~\n\x10ingress_policies\x18\x05 \x03(\x0b\x32\x64.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXIngressPolicies\x12\x8b\x01\n\x17vpc_accessible_services\x18\x06 \x01(\x0b\x32j.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpecXVpcAccessibleServices\"\x85\x01\nXAccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\"\x97\x01\nqAccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xa0\x02\naAccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\xa4\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32\x89\x01.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressToXOperationsXMethodSelectors\"\x97\x02\nVAccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressTo\x12\x1a\n\x12\x65xternal_resources\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x8d\x01\n\noperations\x18\x03 \x03(\x0b\x32y.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressToXOperations\"\xdb\x02\nMAccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPolicies\x12\x85\x01\n\x0b\x65gress_from\x18\x01 \x01(\x0b\x32p.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressFrom\x12\x81\x01\n\tegress_to\x18\x02 \x01(\x0b\x32n.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPoliciesXEgressTo\"\x8c\x01\nbAccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressFromXSources\x12\x14\n\x0c\x61\x63\x63\x65ss_level\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\"\x95\x02\nZAccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressFrom\x12\x12\n\nidentities\x18\x01 \x03(\t\x12\x15\n\ridentity_type\x18\x02 \x01(\t\x12\x8b\x01\n\x07sources\x18\x03 \x03(\x0b\x32z.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressFromXSources\"\x99\x01\nsAccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressToXOperationsXMethodSelectors\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\"\xa4\x02\ncAccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressToXOperations\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\xa6\x01\n\x10method_selectors\x18\x02 \x03(\x0b\x32\x8b\x01.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressToXOperationsXMethodSelectors\"\xff\x01\nXAccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressTo\x12\x11\n\tresources\x18\x01 \x03(\t\x12\x8f\x01\n\noperations\x18\x02 \x03(\x0b\x32{.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressToXOperations\"\xe2\x02\nNAccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPolicies\x12\x88\x01\n\x0cingress_from\x18\x01 \x01(\x0b\x32r.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressFrom\x12\x84\x01\n\ningress_to\x18\x02 \x01(\x0b\x32p.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPoliciesXIngressTo\"\x8c\x01\nTAccessContextManagerServicePerimetersXServicePerimetersXStatusXVpcAccessibleServices\x12\x18\n\x10\x61llowed_services\x18\x01 \x03(\t\x12\x1a\n\x12\x65nable_restriction\x18\x02 \x01(\x08\"\x9a\x04\n>AccessContextManagerServicePerimetersXServicePerimetersXStatus\x12\x15\n\raccess_levels\x18\x01 \x03(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x1b\n\x13restricted_services\x18\x03 \x03(\t\x12~\n\x0f\x65gress_policies\x18\x04 \x03(\x0b\x32\x65.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXEgressPolicies\x12\x80\x01\n\x10ingress_policies\x18\x05 \x03(\x0b\x32\x66.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXIngressPolicies\x12\x8d\x01\n\x17vpc_accessible_services\x18\x06 \x01(\x0b\x32l.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatusXVpcAccessibleServices\"\x9c\x03\n7AccessContextManagerServicePerimetersXServicePerimeters\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x16\n\x0eperimeter_type\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x13\n\x0bupdate_time\x18\x06 \x01(\t\x12!\n\x19use_explicit_dry_run_spec\x18\x07 \x01(\x08\x12\x62\n\x04spec\x18\x08 \x01(\x0b\x32T.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXSpec\x12\x66\n\x06status\x18\t \x01(\x0b\x32V.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimetersXStatus\"`\n.AccessContextManagerServicePerimetersXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc3\x02\n%AccessContextManagerServicePerimeters\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06parent\x18\x02 \x01(\t\x12k\n\x12service_perimeters\x18\x03 \x03(\x0b\x32O.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXServicePerimeters\x12X\n\x08timeouts\x18\x04 \x01(\x0b\x32\x46.oak9.tython.gcp.access.AccessContextManagerServicePerimetersXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_access_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASICXCONDITIONSXDEVICEPOLICYXOSCONSTRAINTS._serialized_start=70
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASICXCONDITIONSXDEVICEPOLICYXOSCONSTRAINTS._serialized_end=225
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASICXCONDITIONSXDEVICEPOLICY._serialized_start=228
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASICXCONDITIONSXDEVICEPOLICY._serialized_end=584
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASICXCONDITIONS._serialized_start=587
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASICXCONDITIONS._serialized_end=853
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASIC._serialized_start=856
  _ACCESSCONTEXTMANAGERACCESSLEVELXBASIC._serialized_end=1017
  _ACCESSCONTEXTMANAGERACCESSLEVELXCUSTOMXEXPR._serialized_start=1019
  _ACCESSCONTEXTMANAGERACCESSLEVELXCUSTOMXEXPR._serialized_end=1138
  _ACCESSCONTEXTMANAGERACCESSLEVELXCUSTOM._serialized_start=1140
  _ACCESSCONTEXTMANAGERACCESSLEVELXCUSTOM._serialized_end=1263
  _ACCESSCONTEXTMANAGERACCESSLEVELXTIMEOUTS._serialized_start=1265
  _ACCESSCONTEXTMANAGERACCESSLEVELXTIMEOUTS._serialized_end=1355
  _ACCESSCONTEXTMANAGERACCESSLEVEL._serialized_start=1358
  _ACCESSCONTEXTMANAGERACCESSLEVEL._serialized_end=1768
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITIONXDEVICEPOLICYXOSCONSTRAINTS._serialized_start=1770
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITIONXDEVICEPOLICYXOSCONSTRAINTS._serialized_end=1881
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITIONXDEVICEPOLICY._serialized_start=1884
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITIONXDEVICEPOLICY._serialized_end=2224
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITIONXTIMEOUTS._serialized_start=2226
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITIONXTIMEOUTS._serialized_end=2309
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITION._serialized_start=2312
  _ACCESSCONTEXTMANAGERACCESSLEVELCONDITION._serialized_end=2746
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASICXCONDITIONSXDEVICEPOLICYXOSCONSTRAINTS._serialized_start=2749
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASICXCONDITIONSXDEVICEPOLICYXOSCONSTRAINTS._serialized_end=2882
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASICXCONDITIONSXDEVICEPOLICY._serialized_start=2885
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASICXCONDITIONSXDEVICEPOLICY._serialized_end=3270
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASICXCONDITIONS._serialized_start=3273
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASICXCONDITIONS._serialized_end=3567
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASIC._serialized_start=3570
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXBASIC._serialized_end=3759
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXCUSTOMXEXPR._serialized_start=3762
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXCUSTOMXEXPR._serialized_end=3895
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXCUSTOM._serialized_start=3898
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELSXCUSTOM._serialized_end=4049
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELS._serialized_start=4052
  _ACCESSCONTEXTMANAGERACCESSLEVELSXACCESSLEVELS._serialized_end=4335
  _ACCESSCONTEXTMANAGERACCESSLEVELSXTIMEOUTS._serialized_start=4337
  _ACCESSCONTEXTMANAGERACCESSLEVELSXTIMEOUTS._serialized_end=4428
  _ACCESSCONTEXTMANAGERACCESSLEVELS._serialized_start=4431
  _ACCESSCONTEXTMANAGERACCESSLEVELS._serialized_end=4729
  _ACCESSCONTEXTMANAGERACCESSPOLICYXTIMEOUTS._serialized_start=4731
  _ACCESSCONTEXTMANAGERACCESSPOLICYXTIMEOUTS._serialized_end=4822
  _ACCESSCONTEXTMANAGERACCESSPOLICY._serialized_start=4825
  _ACCESSCONTEXTMANAGERACCESSPOLICY._serialized_end=5116
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMBINDINGXCONDITION._serialized_start=5118
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMBINDINGXCONDITION._serialized_end=5228
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMBINDING._serialized_start=5231
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMBINDING._serialized_end=5500
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMMEMBERXCONDITION._serialized_start=5502
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMMEMBERXCONDITION._serialized_end=5611
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMMEMBER._serialized_start=5614
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMMEMBER._serialized_end=5880
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMPOLICY._serialized_start=5883
  _ACCESSCONTEXTMANAGERACCESSPOLICYIAMPOLICY._serialized_end=6044
  _ACCESSCONTEXTMANAGERGCPUSERACCESSBINDINGXTIMEOUTS._serialized_start=6046
  _ACCESSCONTEXTMANAGERGCPUSERACCESSBINDINGXTIMEOUTS._serialized_end=6145
  _ACCESSCONTEXTMANAGERGCPUSERACCESSBINDING._serialized_start=6148
  _ACCESSCONTEXTMANAGERGCPUSERACCESSBINDING._serialized_end=6433
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSFROM._serialized_start=6435
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSFROM._serialized_end=6547
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=6550
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=6680
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_start=6683
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_end=6928
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSTO._serialized_start=6931
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIESXEGRESSTO._serialized_end=7167
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIES._serialized_start=7170
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXEGRESSPOLICIES._serialized_end=7452
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_start=7454
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_end=7573
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSFROM._serialized_start=7576
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSFROM._serialized_end=7810
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=7813
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=7945
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_start=7948
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_end=8197
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSTO._serialized_start=8200
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIESXINGRESSTO._serialized_end=8412
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIES._serialized_start=8415
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXINGRESSPOLICIES._serialized_end=8704
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXVPCACCESSIBLESERVICES._serialized_start=8706
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPECXVPCACCESSIBLESERVICES._serialized_end=8825
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPEC._serialized_start=8828
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSPEC._serialized_end=9280
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSFROM._serialized_start=9282
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSFROM._serialized_end=9396
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=9399
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=9531
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_start=9534
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_end=9783
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSTO._serialized_start=9786
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIESXEGRESSTO._serialized_end=10026
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIES._serialized_start=10029
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXEGRESSPOLICIES._serialized_end=10317
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_start=10319
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_end=10440
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSFROM._serialized_start=10443
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSFROM._serialized_end=10681
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=10684
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=10818
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_start=10821
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_end=11074
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSTO._serialized_start=11077
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIESXINGRESSTO._serialized_end=11293
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIES._serialized_start=11296
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXINGRESSPOLICIES._serialized_end=11591
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXVPCACCESSIBLESERVICES._serialized_start=11593
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUSXVPCACCESSIBLESERVICES._serialized_end=11714
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUS._serialized_start=11717
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXSTATUS._serialized_end=12177
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXTIMEOUTS._serialized_start=12179
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERXTIMEOUTS._serialized_end=12274
  _ACCESSCONTEXTMANAGERSERVICEPERIMETER._serialized_start=12277
  _ACCESSCONTEXTMANAGERSERVICEPERIMETER._serialized_end=12806
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERRESOURCEXTIMEOUTS._serialized_start=12808
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERRESOURCEXTIMEOUTS._serialized_end=12895
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERRESOURCE._serialized_start=12898
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERRESOURCE._serialized_end=13152
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSFROM._serialized_start=13155
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSFROM._serialized_end=13286
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=13289
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=13438
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_start=13441
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_end=13725
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSTO._serialized_start=13728
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIESXEGRESSTO._serialized_end=14003
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIES._serialized_start=14006
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXEGRESSPOLICIES._serialized_end=14346
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_start=14349
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_end=14487
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSFROM._serialized_start=14490
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSFROM._serialized_end=14763
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=14766
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=14917
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_start=14920
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_end=15208
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSTO._serialized_start=15211
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIESXINGRESSTO._serialized_end=15462
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIES._serialized_start=15465
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXINGRESSPOLICIES._serialized_end=15813
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXVPCACCESSIBLESERVICES._serialized_start=15816
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPECXVPCACCESSIBLESERVICES._serialized_end=15954
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPEC._serialized_start=15957
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSPEC._serialized_end=16486
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSFROM._serialized_start=16489
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSFROM._serialized_end=16622
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=16625
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=16776
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_start=16779
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSTOXOPERATIONS._serialized_end=17067
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSTO._serialized_start=17070
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIESXEGRESSTO._serialized_end=17349
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIES._serialized_start=17352
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXEGRESSPOLICIES._serialized_end=17699
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_start=17702
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSFROMXSOURCES._serialized_end=17842
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSFROM._serialized_start=17845
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSFROM._serialized_end=18122
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_start=18125
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONSXMETHODSELECTORS._serialized_end=18278
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_start=18281
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSTOXOPERATIONS._serialized_end=18573
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSTO._serialized_start=18576
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIESXINGRESSTO._serialized_end=18831
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIES._serialized_start=18834
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXINGRESSPOLICIES._serialized_end=19188
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXVPCACCESSIBLESERVICES._serialized_start=19191
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUSXVPCACCESSIBLESERVICES._serialized_end=19331
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUS._serialized_start=19334
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERSXSTATUS._serialized_end=19872
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERS._serialized_start=19875
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXSERVICEPERIMETERS._serialized_end=20287
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXTIMEOUTS._serialized_start=20289
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERSXTIMEOUTS._serialized_end=20385
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERS._serialized_start=20388
  _ACCESSCONTEXTMANAGERSERVICEPERIMETERS._serialized_end=20711
# @@protoc_insertion_point(module_scope)



class AwsApiGateway():

    def check_logging_aws_apigateway(apigateway, context):
        """
        Checks that methods in an Amazon API Gateway stage for deployed APIs have 'loggingLevel'
        as one of the values specified in the rule parameter 'loggingLevel'.
        The rule returns NON_COMPLIANT if any method in a stage has 'loggingLevel' set to a
        value not matching any of the logging levels specified in the rule parameter.

        Implements:
            AWS_CONFIG_POLICY: https://github.com/awslabs/aws-config-rules/blob/master/python/API_GW_EXECUTION_LOGGING_ENABLED/API_GW_EXECUTION_LOGGING_ENABLED.py
        Coverage: Full
        """
        violations = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.policy.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.util import intstr_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_util_dot_intstr__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0kubernetes/kubernetes_io.k8s.api.policy.v1.proto\x12\x1doak9.tython.k8s.api.policy.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a?kubernetes/kubernetes_io.k8s.apimachinery.pkg.util.intstr.proto\"\x89\x02\n\x08\x45viction\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12T\n\x0e\x64\x65lete_options\x18\x02 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.DeleteOptions\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12K\n\x08metadata\x18\x04 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xce\x02\n\x13PodDisruptionBudget\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x44\n\x04spec\x18\x04 \x01(\x0b\x32\x36.oak9.tython.k8s.api.policy.v1.PodDisruptionBudgetSpec\x12H\n\x06status\x18\x05 \x01(\x0b\x32\x38.oak9.tython.k8s.api.policy.v1.PodDisruptionBudgetStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x83\x02\n\x17PodDisruptionBudgetList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x41\n\x05items\x18\x02 \x03(\x0b\x32\x32.oak9.tython.k8s.api.policy.v1.PodDisruptionBudget\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xef\x02\n\x17PodDisruptionBudgetSpec\x12R\n\x0fmax_unavailable\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12P\n\rmin_available\x18\x02 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12N\n\x08selector\x18\x03 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12%\n\x1dunhealthy_pod_eviction_policy\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc0\x03\n\x19PodDisruptionBudgetStatus\x12L\n\nconditions\x18\x01 \x03(\x0b\x32\x38.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Condition\x12\x17\n\x0f\x63urrent_healthy\x18\x02 \x01(\x05\x12\x17\n\x0f\x64\x65sired_healthy\x18\x03 \x01(\x05\x12\x63\n\x0e\x64isrupted_pods\x18\x04 \x03(\x0b\x32K.oak9.tython.k8s.api.policy.v1.PodDisruptionBudgetStatus.DisruptedPodsEntry\x12\x1b\n\x13\x64isruptions_allowed\x18\x05 \x01(\x05\x12\x15\n\rexpected_pods\x18\x06 \x01(\x05\x12\x1b\n\x13observed_generation\x18\x07 \x01(\x05\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x34\n\x12\x44isruptedPodsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.policy.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PODDISRUPTIONBUDGETSTATUS_DISRUPTEDPODSENTRY._options = None
  _PODDISRUPTIONBUDGETSTATUS_DISRUPTEDPODSENTRY._serialized_options = b'8\001'
  _EVICTION._serialized_start=236
  _EVICTION._serialized_end=501
  _PODDISRUPTIONBUDGET._serialized_start=504
  _PODDISRUPTIONBUDGET._serialized_end=838
  _PODDISRUPTIONBUDGETLIST._serialized_start=841
  _PODDISRUPTIONBUDGETLIST._serialized_end=1100
  _PODDISRUPTIONBUDGETSPEC._serialized_start=1103
  _PODDISRUPTIONBUDGETSPEC._serialized_end=1470
  _PODDISRUPTIONBUDGETSTATUS._serialized_start=1473
  _PODDISRUPTIONBUDGETSTATUS._serialized_end=1921
  _PODDISRUPTIONBUDGETSTATUS_DISRUPTEDPODSENTRY._serialized_start=1869
  _PODDISRUPTIONBUDGETSTATUS_DISRUPTEDPODSENTRY._serialized_end=1921
# @@protoc_insertion_point(module_scope)
